<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>すべて消去</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>通知センター</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>すべて消去</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>固定解除</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>固定</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>通知の設定</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>たった今</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1分前</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1時間前</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1時間前</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>昨日</translation>
    </message>
</context>
</TS>